@@ -2,6 +2,7 @@
    Copyright © 1999, 2000 Progiciels Bourbeau-Pinard inc.
    François Pinard <pinard@iro.umontreal.ca>, 1997.  */
 
+#include "config.h"
 #include "common.h"
 #include "decsteps.h"
 
@@ -121,6 +122,6 @@ module_african (RECODE_OUTER outer)
 }
 
 void
-delmodule_african (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
+delmodule_african (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED)
 {
 }
