@@ -17,6 +17,7 @@
    If not, see <https://www.gnu.org/licenses/>.
 */
 
+#include "config.h"
 #include "common.h"
 #include "decsteps.h"
 
@@ -435,6 +436,6 @@ module_dump (RECODE_OUTER outer)
 }
 
 void
-delmodule_dump (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
+delmodule_dump (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED)
 {
 }
