@@ -17,6 +17,7 @@
    If not, see <https://www.gnu.org/licenses/>.
 */
 
+#include "config.h"
 #include "common.h"
 #include "decsteps.h"
 
@@ -171,6 +172,6 @@ module_endline (RECODE_OUTER outer)
 }
 
 void
-delmodule_endline (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
+delmodule_endline (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED)
 {
 }
