@@ -18,6 +18,7 @@
    If not, see <https://www.gnu.org/licenses/>.
 */
 
+#include "config.h"
 #include "common.h"
 #include "decsteps.h"
 #include <iconv.h>
@@ -240,6 +241,6 @@ module_iconv (RECODE_OUTER outer)
 }
 
 void
-delmodule_iconv (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
+delmodule_iconv (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED)
 {
 }
