@@ -17,6 +17,7 @@
    If not, see <https://www.gnu.org/licenses/>.
 */
 
+#include "config.h"
 #include "common.h"
 #include "decsteps.h"
 
@@ -111,7 +112,7 @@ module_java (RECODE_OUTER outer)
 		       NULL, transform_java_utf16);
 }
 
-_GL_ATTRIBUTE_CONST void
-delmodule_java (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
+void
+delmodule_java (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED)
 {
 }
