@@ -29,6 +29,7 @@
 */
 
 
+#include "config.h"
 #include "common.h"
 #include "decsteps.h"
 
@@ -47,8 +48,8 @@ static struct translation diacritic_translations [] =
 static bool
 init_latin1_ansel (RECODE_STEP step,
 		   const struct recode_request *request,
-		   RECODE_CONST_OPTION_LIST before_options _GL_UNUSED_PARAMETER,
-		   RECODE_CONST_OPTION_LIST after_options _GL_UNUSED_PARAMETER)
+		   RECODE_CONST_OPTION_LIST before_options _GL_ATTRIBUTE_MAYBE_UNUSED,
+		   RECODE_CONST_OPTION_LIST after_options _GL_ATTRIBUTE_MAYBE_UNUSED)
 {
   RECODE_OUTER outer = request->outer;
   
@@ -87,6 +88,6 @@ module_latin1_ansel (RECODE_OUTER outer)
 }
 
 void
-delmodule_latin1_ansel (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
+delmodule_latin1_ansel (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED)
 {
 }
