@@ -18,6 +18,7 @@
    If not, see <https://www.gnu.org/licenses/>.
    Suite 330, Boston, MA 02111-1307, USA.  */
 
+#include "config.h"
 #include "common.h"
 #include "decsteps.h"
 
@@ -178,6 +179,6 @@ module_latin1_bibtex (RECODE_OUTER outer)
 }
 
 void
-delmodule_latin1_bibtex (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
+delmodule_latin1_bibtex (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED)
 {
 }
