@@ -17,6 +17,7 @@
    If not, see <https://www.gnu.org/licenses/>.
 */
 
+#include "config.h"
 #include "common.h"
 #include "decsteps.h"
 
@@ -225,6 +226,6 @@ module_latin1_texte (RECODE_OUTER outer)
 }
 
 void
-delmodule_latin1_texte (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
+delmodule_latin1_texte (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED)
 {
 }
