@@ -16,10 +16,9 @@
    along with this program; if not, see <https://www.gnu.org/licenses/>.
 */
 
+#include "config.h"
 #include "common.h"
 
-#include <stdlib.h>
-#include <stdio.h>
 #include <ctype.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -243,6 +242,7 @@ Fine tuning:\n\
   -c, --colons           use colons instead of double quotes for diaeresis\n\
   -g, --graphics         approximate IBMPC rulers by ASCII graphics\n\
   -x, --ignore=CHARSET   ignore CHARSET while choosing a recoding path\n\
+  -I, --prefer-iconv     use iconv if possible\n\
 "),
 	     stdout);
       fputs (_("\
@@ -303,6 +303,7 @@ static const struct option long_options[] =
   {"ignore", required_argument, NULL, 'x'},
   {"known", required_argument, NULL, 'k'},
   {"list", optional_argument, NULL, 'l'},
+  {"prefer-iconv", no_argument, NULL, 'I'},
   {"quiet", no_argument, NULL, 'q'},
   {"sequence", required_argument, NULL, '\n'},
   {"source", optional_argument, NULL, 'S'},
@@ -323,6 +324,57 @@ static const char *const language_strings[]
 static const char *const sequence_strings[]
   = { "memory", "files", "pipe", NULL };
 
+
+static RECODE_OUTER
+new_outer(unsigned flags)
+{
+  /* Register all modules and build internal tables.  */
+
+  RECODE_OUTER outer = recode_new_outer (flags | RECODE_AUTO_ABORT_FLAG);
+  if (!outer)
+    abort ();
+
+  /* Set strict mapping.  */
+
+  if (strict_mapping)
+    {
+      RECODE_SINGLE single;
+
+      for (single = outer->single_list; single; single = single->next)
+	single->fallback_routine = NULL;
+    }
+
+  /* Set the ignored charset.  */
+
+  if (ignored_name)
+    {
+      RECODE_ALIAS alias
+	= find_alias (outer, ignored_name, ALIAS_FIND_AS_CHARSET);
+
+      if (!alias)
+	{
+	  error (0, 0, _("Symbol `%s' is unknown"), ignored_name);
+	  usage (EXIT_FAILURE, 1);
+	}
+
+      alias->symbol->ignore = true;
+    }
+
+  return outer;
+}
+
+static RECODE_REQUEST
+new_request(RECODE_OUTER outer, struct recode_request *request_option)
+{
+  RECODE_REQUEST request = recode_new_request (outer);
+  request->ascii_graphics = request_option->ascii_graphics;
+  request->diacritics_only = request_option->diacritics_only;
+  request->diaeresis_char = request_option->diaeresis_char;
+  request->make_header_flag = request_option->make_header_flag;
+  request->verbose_flag = request_option->verbose_flag;
+  return request;
+}
+
 int
 main (int argc, char *const *argv)
 {
@@ -334,9 +386,6 @@ main (int argc, char *const *argv)
   struct recode_request request_option;
   struct recode_task task_option;
 
-  RECODE_OUTER outer;
-  RECODE_REQUEST request;
-
   program_name = argv[0];
   /* libtool creates a temporary executable whose names is prefixed with
      "lt-".  Remove this prefix here.  */
@@ -360,7 +409,7 @@ main (int argc, char *const *argv)
   task_option.fail_level = RECODE_AMBIGUOUS_OUTPUT;
   task_option.abort_level = RECODE_AMBIGUOUS_OUTPUT;
 
-  while (option_char = getopt_long (argc, argv, "CFS::Tcdfgh::ik:l::pqstvx:",
+  while (option_char = getopt_long (argc, argv, "CIFS::Tcdfgh::ik:l::pqstvx:",
 				    long_options, NULL),
 	 option_char != -1)
     switch (option_char)
@@ -399,6 +448,10 @@ main (int argc, char *const *argv)
 	print_copyright ();
 	exit (EXIT_SUCCESS);
 
+      case 'I':
+        request_option.prefer_iconv = true;
+        break;
+
       case 'S':
 	if (optarg)
 	  switch (argmatch (optarg, language_strings, NULL, 0))
@@ -575,7 +628,7 @@ Written by François Pinard <pinard@iro.umontreal.ca>.\n"),
 	     stdout);
       fputs (_("\
 \n\
-Copyright (C) 1990-2018 Free Software Foundation, Inc.\n"),
+Copyright (C) 1990-2022 Free Software Foundation, Inc.\n"),
 	     stdout);
       fputs (_("\
 This is free software; see the source for copying conditions.  There is NO\n\
@@ -587,53 +640,20 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"),
   if (show_help)
     usage (EXIT_SUCCESS, 0);
 
-  /* Register all modules and build internal tables.  */
+  /* Set up the outer level.  */
 
-  {
-    unsigned flags = RECODE_AUTO_ABORT_FLAG;
-    if (ignored_name && *ignored_name == ':')
-      flags |= RECODE_NO_ICONV_FLAG;
-    if (request_option.make_header_flag)
-      flags |= RECODE_NO_ICONV_FLAG;
-    outer = recode_new_outer (flags);
-    if (!outer)
-      abort ();
-  }
-
-  /* Set strict mapping.  */
-
-  if (strict_mapping)
-    {
-      RECODE_SINGLE single;
-
-      for (single = outer->single_list; single; single = single->next)
-	single->fallback_routine = NULL;
-    }
-
-  /* Set the ignored charset.  */
-
-  if (ignored_name)
-    {
-      RECODE_ALIAS alias
-	= find_alias (outer, ignored_name, ALIAS_FIND_AS_CHARSET);
-
-      if (!alias)
-	{
-	  error (0, 0, _("Symbol `%s' is unknown"), ignored_name);
-	  usage (EXIT_FAILURE, 1);
-	}
-
-      alias->symbol->ignore = true;
-    }
+  unsigned flags = 0;
+  if ((ignored_name && *ignored_name == ':')
+      || request_option.make_header_flag)
+    flags |= RECODE_NO_ICONV_FLAG;
+  RECODE_OUTER outer = new_outer (flags);
 
   /* Process charset listing options.  */
 
   if (find_subsets)
     {
-      if (find_and_report_subsets (outer))
-	exit (EXIT_SUCCESS);
-      else
-	exit (EXIT_FAILURE);
+      find_and_report_subsets (outer);
+      exit (EXIT_SUCCESS);
     }
 
   if (show_symbols || charset_restrictions)
@@ -643,6 +663,7 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"),
 	  {
 	    error (0, 0, "Could not understand `%s'", charset_restrictions);
 	    usage (EXIT_FAILURE, 0);
+
 	  }
       if (optind + 1 < argc)
 	{
@@ -708,54 +729,12 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"),
       usage (EXIT_FAILURE, 0);
     }
 
-  request = recode_new_request (outer);
-  request->ascii_graphics = request_option.ascii_graphics;
-  request->diacritics_only = request_option.diacritics_only;
-  request->diaeresis_char = request_option.diaeresis_char;
-  request->make_header_flag = request_option.make_header_flag;
-  request->verbose_flag = request_option.verbose_flag;
+  RECODE_REQUEST request = new_request (outer, &request_option);
 
-  {
-    const char *user_request = argv[optind++];
-    char *rewritten_request = NULL;
-    const char *colon = strchr (user_request, ':');
+  const char *user_request = argv[optind];
 
-    /* Try to detect old syntax, that is, no `..' and a single `:'.  In such
-       case, issue a warning, and rewrite the request to new syntax.  */
-
-    if (colon && !strchr (colon + 1, ':'))
-      {
-	const char *cursor;
-
-	for (cursor = user_request; *cursor; cursor++)
-	  if (cursor[0] == '.' && cursor[1] == '.')
-	    break;
-
-	if (!*cursor)
-	  {
-	    char *cursor2;
-
-	    rewritten_request = (char *) xmalloc (strlen (user_request) + 2);
-	    cursor2 = rewritten_request;
-	    for (cursor = user_request; *cursor != ':'; cursor++)
-	      *cursor2++ = *cursor;
-	    *cursor2++ = '.';
-	    *cursor2++ = '.';
-	    for (cursor++; *cursor; cursor++)
-	      *cursor2++ = *cursor;
-	    *cursor2 = NUL;
-
-	    user_request = rewritten_request;
-	    if (!quiet_flag)
-	      error (0, 0, _("Syntax is deprecated, please prefer `%s'"),
-		     user_request);
-	  }
-      }
-
-    if (!recode_scan_request (request, user_request))
-      error (EXIT_FAILURE, 0, _("Request `%s' is erroneous"), user_request);
-    free (rewritten_request);
-  }
+  if (!recode_scan_request (request, user_request))
+    error (EXIT_FAILURE, 0, _("Request `%s' is erroneous"), user_request);
 
   /* If we merely want source code, do it and get out.  */
 
@@ -765,6 +744,27 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"),
       exit (EXIT_SUCCESS);
     }
 
+  /* If we are recoding, and we are allowed to use iconv, and --prefer-iconv
+     was not used, see if we can do it without iconv.  */
+
+  if ((flags & RECODE_NO_ICONV_FLAG) == 0 && !request_option.prefer_iconv)
+    {
+      RECODE_OUTER no_iconv_outer = new_outer (RECODE_NO_ICONV_FLAG);
+      RECODE_REQUEST no_iconv_request =
+        new_request (no_iconv_outer, &request_option);
+
+      if (recode_scan_request (no_iconv_request, user_request))
+        {
+          recode_delete_request (request);
+          recode_delete_outer (outer);
+          outer = no_iconv_outer;
+          request = no_iconv_request;
+        }
+    }
+
+  /* Discard the request argument.  */
+  optind++;
+
 #if HAVE_PIPE
   setup_signals ();
 #endif
