@@ -17,6 +17,7 @@
    If not, see <https://www.gnu.org/licenses/>.
 */
 
+#include "config.h"
 #include "common.h"
 #include "decsteps.h"
 
@@ -361,6 +362,6 @@ module_quoted_printable (RECODE_OUTER outer)
 }
 
 void
-delmodule_quoted_printable (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
+delmodule_quoted_printable (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED)
 {
 }
