@@ -17,6 +17,7 @@
    If not, see <https://www.gnu.org/licenses/>.
 */
 
+#include "config.h"
 #include "common.h"
 
 /* Global declarations and definitions.  */
@@ -33,8 +34,8 @@ extern const char *program_name;
 
 #include <stdarg.h>
 
-_GL_ATTRIBUTE_FORMAT_PRINTF (2, 3) void
-recode_error (RECODE_OUTER outer _GL_UNUSED_PARAMETER, const char *format, ...)
+_GL_ATTRIBUTE_FORMAT_PRINTF_SYSTEM (2, 3) void
+recode_error (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED, const char *format, ...)
 {
   va_list args;
 
@@ -45,8 +46,8 @@ recode_error (RECODE_OUTER outer _GL_UNUSED_PARAMETER, const char *format, ...)
   fflush (stderr);
 }
 
-_GL_ATTRIBUTE_FORMAT_PRINTF (2, 3) void
-recode_perror (RECODE_OUTER outer _GL_UNUSED_PARAMETER, const char *format, ...)
+_GL_ATTRIBUTE_FORMAT_PRINTF_SYSTEM (2, 3) void
+recode_perror (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED, const char *format, ...)
 {
   int saved_errno = errno;
   va_list args;
@@ -58,7 +59,7 @@ recode_perror (RECODE_OUTER outer _GL_UNUSED_PARAMETER, const char *format, ...)
   fflush (stderr);
 }
 
-void *
+_GL_ATTRIBUTE_MALLOC void *
 recode_malloc (RECODE_OUTER outer, size_t size)
 {
   void *result;
