@@ -17,6 +17,7 @@
    If not, see <https://www.gnu.org/licenses/>.
 */
 
+#include "config.h"
 #include "common.h"
 #include "decsteps.h"
 #include "rfc1345.h"
@@ -237,7 +238,7 @@ term_rfc1345 (RECODE_STEP step)
 static bool
 init_rfc1345 (RECODE_CONST_REQUEST request,
 	      RECODE_STEP step,
-	      RECODE_CONST_OPTION_LIST options _GL_UNUSED_PARAMETER)
+	      RECODE_CONST_OPTION_LIST options _GL_ATTRIBUTE_MAYBE_UNUSED)
 {
   RECODE_OUTER outer = request->outer;
   struct local *local;
@@ -306,6 +307,6 @@ module_rfc1345 (RECODE_OUTER outer)
 }
 
 void
-delmodule_rfc1345 (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
+delmodule_rfc1345 (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED)
 {
 }
