@@ -17,6 +17,7 @@
    If not, see <https://www.gnu.org/licenses/>.
 */
 
+#include "config.h"
 #include "common.h"
 #include "decsteps.h"
 #include "hash.h"
@@ -386,6 +387,6 @@ module_testdump (RECODE_OUTER outer)
 }
 
 void
-delmodule_testdump (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
+delmodule_testdump (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED)
 {
 }
