@@ -17,6 +17,7 @@
    If not, see <https://www.gnu.org/licenses/>.
 */
 
+#include "config.h"
 #include "common.h"
 #include "decsteps.h"
 
@@ -246,6 +247,6 @@ module_utf8 (RECODE_OUTER outer)
 }
 
 void
-delmodule_utf8 (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
+delmodule_utf8 (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED)
 {
 }
