@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # -*- coding: utf-8 -*-
 # Automatically derive Recode table files from various sources.
 # Copyright © 1993, 1994, 1997, 1998, 1999, 2000 Free Software Foundation, Inc.
@@ -40,7 +40,7 @@ from Keld's chset* packages.  The digesting order is usually important.
 When `-F' and `-n' are used, process Alain's tables.
 """
 
-import re, sys
+import re, sys, io
 
 # Character constants.
 REPLACEMENT_CHARACTER = 0xFFFD
@@ -200,12 +200,11 @@ class Charnames(Options):
 
     def digest_french(self, input):
         self.preset_french()
-        fold_table = range(256)
-        for before, after in map(
-                None,
+        fold_table = list(range(256))
+        for before, after in zip(
                 u'ABCDEFGHIJKLMNOPQRSTUVWXYZÀÂÇÈÉÊÎÏÑÔÖÛ'.encode('ISO-8859-1'),
                 u'abcdefghijklmnopqrstuvwxyzàâçèéêîïñôöû'.encode('ISO-8859-1')):
-            fold_table[ord(before)] = ord(after)
+            fold_table[before] = after
         folding = ''.join(map(chr, fold_table))
         ignorables = (
                 u'<commande>'.encode('ISO-8859-1'),
@@ -267,7 +266,7 @@ class Charnames(Options):
             u"séparateur d'article (rs)",                        # 001E
             u"séparateur de sous-article (us)",                  # 001F
             ):
-            self.declare(ucs, text.encode('ISO-8859-1'))
+            self.declare(ucs, text)
             ucs += 1
         ucs = 0x007F
         for text in (
@@ -305,7 +304,7 @@ class Charnames(Options):
             u"message privé (pm)",                               # 009E
             u"commande de progiciel (apc)",                      # 009F
             ):
-            self.declare(ucs, text.encode('ISO-8859-1'))
+            self.declare(ucs, text)
             ucs += 1
 
     def declare(self, ucs, text):
@@ -333,18 +332,18 @@ class Charnames(Options):
         # the second cycling faster from 1 to 255.
         if run.verbose:
             sys.stdout.write('  sorting words...')
-        pairs = map(self.presort_word, self.code_map.keys())
+        pairs = list(map(self.presort_word, self.code_map.keys()))
         pairs.sort()
-        words = map(lambda pair: pair[1], pairs)
+        words = list(map(lambda pair: pair[1], pairs))
         pairs = None
         if run.verbose:
             sys.stdout.write(' %d of them\n' % len(words))
         count = len(words)
-        singles = (255 * 255 - count) / 254
+        singles = (255 * 255 - count) // 254
         # Transmit a few values for further usage by the C code.
         if run.verbose:
             sys.stdout.write('  sorting names...')
-        ucs2_table = self.charname_map.keys()
+        ucs2_table = list(self.charname_map.keys())
         ucs2_table.sort()
         if run.verbose:
             sys.stdout.write(' %d of them\n' % len(ucs2_table))
@@ -396,7 +395,7 @@ class Charnames(Options):
                     if code < 256:
                         write('\\%0.3o' % code)
                     else:
-                        write('\\%0.3o\\%0.3o' % (code / 256, code % 256))
+                        write('\\%0.3o\\%0.3o' % (code // 256, code % 256))
                 else:
                     sys.stdout.write('??? %s\n' % word)
             write('"},\n')
@@ -413,6 +412,7 @@ class Explodes(Options):
         self.write = Output(self.SOURCES).write
         write = self.write
         write('\n'
+              '#include "config.h"\n'
               '#include "common.h"\n')
 
     def complete(self, french):
@@ -442,7 +442,7 @@ class Explodes(Options):
               '  return true;\n'
               '}\n'
               '\n'
-              '_GL_ATTRIBUTE_CONST void\n'
+              'void\n'
               'delmodule_explodes (struct recode_outer *outer _GL_UNUSED_PARAMETER)\n'
               '{\n'
               '}\n')
@@ -666,7 +666,7 @@ class Mnemonics(Options):
               'static const struct entry table[TABLE_LENGTH] =\n'
               '  {\n')
         count = 0
-        indices = self.mnemonic_map.keys()
+        indices = list(self.mnemonic_map.keys())
         indices.sort()
         for ucs2 in indices:
             text = self.mnemonic_map[ucs2]
@@ -680,7 +680,7 @@ class Mnemonics(Options):
               'static const unsigned short inverse[TABLE_LENGTH] =\n'
               '  {')
         count = 0
-        keys = inverse_map.keys()
+        keys = list(inverse_map.keys())
         keys.sort()
         for text in keys:
             if count % 10 == 0:
@@ -735,6 +735,7 @@ class Strips(Options):
             self.write_data = Output(self.DATA).write
             write = self.write_data
             write('\n'
+                  '#include "config.h"\n'
                   '#include "common.h"\n'
                   '#include "decsteps.h"\n')
 
@@ -1092,7 +1093,7 @@ class Strips(Options):
               '  return true;\n'
               '}\n'
               '\n'
-              '_GL_ATTRIBUTE_CONST void\n'
+              'void\n'
               'delmodule_strips (struct recode_outer *outer _GL_UNUSED_PARAMETER)\n'
               '{\n'
               '}\n')
@@ -1100,6 +1101,7 @@ class Strips(Options):
         # Write the pool file.
         write = Output(self.POOL).write
         write('\n'
+              '#include "config.h"\n'
               '#include "common.h"\n'
               '\n'
               'const recode_ucs2 ucs2_data_pool[%d] =\n'
@@ -1124,7 +1126,7 @@ class Strips(Options):
             write = Output('fr-%s' % self.TEXINFO, noheader=True).write
         else:
             write = Output(self.TEXINFO, noheader=True).write
-        charsets = self.remark_map.keys()
+        charsets = list(self.remark_map.keys())
         charsets.sort()
         for charset in charsets:
             write('\n'
@@ -1160,13 +1162,15 @@ class Input:
 
     def __init__(self, name):
         self.name = name
-        self.input = file(name)
+        self.input = io.open(name, encoding='latin-1')
         self.line_count = 0
         sys.stdout.write("Reading %s\n" % name)
 
     def readline(self):
         self.line = self.input.readline()
         self.line_count += 1
+        if type(self.line) == bytes:
+            self.line = self.line.decode('utf-8')
         return self.line
 
     def warn(self, format, *args):
@@ -1192,7 +1196,7 @@ class Output:
 
     def __init__(self, name, noheader=False):
         self.name = name
-        self.write = file(name, 'w').write
+        self.write = open(name, 'w', encoding='utf-8').write
         sys.stdout.write("Writing %s\n" % name)
         if not noheader:
             self.write("""\
